@@ -1,3 +1,3 @@
 from .features import extract_feature
-from .model import model_load
+from .model_final import model_load
 from .predict import summary, predict
